#!/bin/bash

. ./cmd.sh 
. ./path.sh 

# DNNの学習

config=config_opt_demo
. $config
gmmdir=../04_sat/exp/tri4
data_fmllr=../data-fmllr-tri4

. utils/parse_options.sh || exit 1;

# RBMを用いたプレトレーニング
dir=exp/dnn5b_pretrain-dbn
$cuda_cmd $dir/log/pretrain_dbn.log \
    ./pretrain_dbn.sh --config $config --rbm-iter 1 --skip-cuda-check true $data_fmllr/train_nodup $dir || exit 1;

# クロスエントロピーを用いたファインチューニング
dir=exp/dnn5b_pretrain-dbn_dnn
ali=${gmmdir}_ali_nodup
feature_transform=exp/dnn5b_pretrain-dbn/final.feature_transform
dbn=exp/dnn5b_pretrain-dbn/${nn_depth}.dbn
$cuda_cmd $dir/log/train_nnet.log \
    ./train.sh --config $config --feature-transform $feature_transform --dbn $dbn --hid-layers 0 --learn-rate $learn_rate --skip-cuda-check true\
    $data_fmllr/train_nodup_tr90 $data_fmllr/train_nodup_cv10 ../data/lang $ali $ali $dir || exit 1;

# Decode with the trigram csj language model.
for eval_num in `seq 1`; do
    # 認識(ここは簡単のためラティスを作らずに認識)
    local/decode_dnn_nolats.sh --nj 1 --cmd "$decode_cmd" --config conf/decode_dnn.config --skip-scoring true --acwt 0.08333 \
	$gmmdir/graph_csj_tg $data_fmllr/eval${eval_num} $dir/decode_eval${eval_num}_csj || exit 1;
    # 認識率の計算
    zcat $dir/decode_eval${eval_num}_csj/words.*.gz | copy-int-vector ark:- ark,t:- >$dir/decode_eval${eval_num}_csj/nolats_int.hyp
    int2sym.pl -f 2: ../data/lang_csj_tg/words.txt  $dir/decode_eval${eval_num}_csj/nolats_int.hyp | local/wer_hyp_filter >$dir/decode_eval${eval_num}_csj/nolats_stem.hyp
    compute-wer --mode=all --text ark:test.ref  ark:$dir/decode_eval${eval_num}_csj/nolats_stem.hyp >$dir/decode_eval${eval_num}_csj/wer_nolats
done

