#!/bin/bash

. ./cmd.sh 
. ./path.sh

# DNNのSequence学習

config=conf/config_opt
. $config
gmmdir=../04_sat/exp/tri4
data_fmllr=../data-fmllr-tri4

. utils/parse_options.sh || exit 1;

# Sequence training using sMBR criterion, we do Stochastic-GD 
# with per-utterance updates. We use usually good acwt 0.1
# Lattices are re-generated after 1st epoch, to get faster convergence.
dir=exp/dnn5b_pretrain-dbn_dnn_smbr
srcdir=../08_dnn/exp/dnn5b_pretrain-dbn_dnn
acwt=0.0909

## アライメントとラティスの生成
## First we generate lattices and alignments:
## alignment
steps/nnet/align.sh --nj 1 --cmd "$train_cmd" \
  $data_fmllr/train_nodup ../data/lang $srcdir exp/dnn5b_pretrain-dbn_dnn_ali || exit 1;
## denlats
steps/nnet/make_denlats.sh --nj 1 --sub-split 1 --cmd "$decode_cmd" --config conf/decode_dnn.config \
  --acwt $acwt $data_fmllr/train_nodup ../data/lang $srcdir exp/dnn5b_pretrain-dbn_dnn_denlats || exit 1;


# Re-train the DNN by 1 iteration of sMBR 
steps/nnet/train_mpe.sh --cmd "$cuda_cmd" --num-iters 1 --acwt $acwt --do-smbr true --skip-cuda-check true \
  $data_fmllr/train_nodup ../data/lang $srcdir exp/dnn5b_pretrain-dbn_dnn_ali exp/dnn5b_pretrain-dbn_dnn_denlats $dir || exit 1

for eval_num in `seq 1`; do
    # 認識
    local/decode_dnn_nolats.sh --nj 1 --cmd "$decode_cmd" --config conf/decode_dnn.config \
	--skip-scoring true --nnet $dir/1.nnet --acwt $acwt \
	$gmmdir/graph_csj_tg $data_fmllr/eval${eval_num} $dir/decode_eval${eval_num}_csj || exit 1;
    # 認識率の計算
    zcat $dir/decode_eval${eval_num}_csj/words.*.gz | copy-int-vector ark:- ark,t:- >$dir/decode_eval${eval_num}_csj/nolats_int.hyp
    int2sym.pl -f 2: ../data/lang_csj_tg/words.txt  $dir/decode_eval${eval_num}_csj/nolats_int.hyp | local/wer_hyp_filter >$dir/decode_eval${eval_num}_csj/nolats_stem.hyp
    compute-wer --mode=all --text ark:test.ref  ark:$dir/decode_eval${eval_num}_csj/nolats_stem.hyp >$dir/decode_eval${eval_num}_csj/wer_nolats
done

